From 20099b94e6f8f0881f84624bc4b50489ff02a431 Mon Sep 17 00:00:00 2001 From: =?UTF-8?q?Martin=20Storsj=C3=B6?= Date: Thu, 3 Apr 2025 10:05:49 +0300 Subject: [PATCH] build-mingw-w64: Use silent rules for compiling things This reduces the amount of log output significantly. For the linux build on github actions, this reduces the log output from 8.5 MB down to 4.7 MB. --- build-mingw-w64-libraries.sh | 1 + build-mingw-w64-tools.sh | 2 ++ build-mingw-w64.sh | 1 + 3 files changed, 4 insertions(+) diff --git a/build-mingw-w64-libraries.sh b/build-mingw-w64-libraries.sh index ccbda60..dd121ea 100755 --- a/build-mingw-w64-libraries.sh +++ b/build-mingw-w64-libraries.sh @@ -64,6 +64,7 @@ for lib in winpthreads winstorecompat; do cd build-$arch arch_prefix="$PREFIX/$arch-w64-mingw32" ../configure --host=$arch-w64-mingw32 --prefix="$arch_prefix" --libdir="$arch_prefix/lib" \ + --enable-silent-rules \ CFLAGS="$USE_CFLAGS" \ CXXFLAGS="$USE_CFLAGS" $MAKE -j$CORES diff --git a/build-mingw-w64-tools.sh b/build-mingw-w64-tools.sh index a7ff8e2..c6ce7fe 100755 --- a/build-mingw-w64-tools.sh +++ b/build-mingw-w64-tools.sh @@ -104,6 +104,8 @@ else fi ANY_ARCH=$(echo $ARCHS | awk '{print $1}') +CONFIGFLAGS="$CONFIGFLAGS --enable-silent-rules" + cd mingw-w64-tools/gendef [ -z "$CLEAN" ] || rm -rf build${CROSS_NAME} mkdir -p build${CROSS_NAME} diff --git a/build-mingw-w64.sh b/build-mingw-w64.sh index ae96086..9c3a64b 100755 --- a/build-mingw-w64.sh +++ b/build-mingw-w64.sh @@ -132,6 +132,7 @@ for arch in $ARCHS; do ;; esac FLAGS="$FLAGS --with-default-msvcrt=$DEFAULT_MSVCRT" + FLAGS="$FLAGS --enable-silent-rules" ../configure --host=$arch-w64-mingw32 --prefix="$PREFIX/$arch-w64-mingw32" $FLAGS $CFGUARD_FLAGS $CRT_CONFIG_FLAGS $MAKE -j$CORES $MAKE install